@@ -50,7 +50,7 @@ from teslajsonpy.homeassistant.lock import ChargerLock, Lock
 from teslajsonpy.homeassistant.sentry_mode import SentryModeSwitch
 from teslajsonpy.homeassistant.trunk import FrunkLock, TrunkLock
 from teslajsonpy.homeassistant.heated_steering_wheel import HeatedSteeringWheelSwitch
-from teslajsonpy.homeassistant.power import PowerSensor
+from teslajsonpy.homeassistant.power import PowerSensor, TESLA_DEFAULT_ENEREGY_SITE_NAME
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -169,7 +169,7 @@ async def wake_up(wrapped, instance, args, kwargs) -> Callable:
                 "Exception: %s\n%s(%s %s)", str(ex), wrapped.__name__, args, kwargs
             )
             raise
-    if valid_result(result) or is_wake_command or is_energysite_command:
+    if valid_result(result) or is_wake_command or is_energysite_command or instance._id_to_vin(car_id) is None:
         return result
     _LOGGER.debug(
         "wake_up needed for %s -> %s \n"
@@ -182,9 +182,6 @@ async def wake_up(wrapped, instance, args, kwargs) -> Callable:
         car_id if car_id else None,
         instance.car_online if instance.car_online else None,
     )
-    # if we got here and it's an energy site that doesn't go to sleep, there is a problem; raise an exception
-    if is_energysite_command:
-        raise TeslaException("could_not_read_energy_site")
     instance.car_online[instance._id_to_vin(car_id)] = False
     while (
         kwargs.get("wake_if_asleep")
@@ -366,7 +363,7 @@ class Controller:
             energysite_id = energysite["energy_site_id"]
             self.__id_energysiteid_map[energysite["id"]] = energysite_id
             self.__energysiteid_id_map[energysite_id] = energysite["id"]
-            self.__energysite_name[energysite_id] = energysite["site_name"]
+            self.__energysite_name[energysite_id] = energysite.get("site_name", TESLA_DEFAULT_ENEREGY_SITE_NAME)
             self.__energysite_type[energysite_id] = energysite["solar_type"]
             self.__power[energysite_id] = {"solar_power": energysite["solar_power"]}
             self.__lock[energysite_id] = asyncio.Lock()
@@ -600,7 +597,7 @@ class Controller:
     ):
         """Post name command to the car_id.
 
-        This will be deprecated. Use self.api instead.
+        This will be deprecated. Use :meth:`teslajsonpy.Controller.api` instead.
 
         Parameters
         ----------
@@ -831,7 +828,6 @@ class Controller:
                         "SITE_DATA",
                         path_vars={"site_id": energysite_id},
                         wake_if_asleep=wake_if_asleep,
-                        product_type=TESLA_PRODUCT_TYPE_ENERGY_SITES,
                     )
                 except TeslaException:
                     data = None
@@ -1138,18 +1134,31 @@ class Controller:
 
         Code from https://github.com/tdorssers/TeslaPy/blob/master/teslapy/__init__.py#L242-L277 under MIT
 
-        Args
-            name (str): Endpoint name, e.g., STATUS
-            path_vars (dict, optional): Path variables to be replaced. Defaults to None.
-            wake_if_asleep (bool, optional): Whether to wake up any sleeping cars to update state. Defaults to False.
+        Parameters
+        ----------
+        name : string
+            Endpoint command, e.g., STATUS. See https://github.com/zabuldon/teslajsonpy/blob/dev/teslajsonpy/endpoints.json
+        path_vars : dict
+            Path variables to be replaced. Defaults to None. For vehicle_id reference see https://tesla-api.timdorr.com/api-basics/vehicles#vehicle_id-vs-id
+        wake_if_asleep : bool
+            Function for underlying api call for whether a failed response
+            should wake up the vehicle or retry.
+        **kwargs :
+            Arguments to pass to underlying Tesla command. See https://tesla-api.timdorr.com/vehicle/commands
 
         Raises
-            ValueError: If endpoint name is not found
-            NotImplementedError: Endpoint method not implemented
-            ValueError: Path variables missing
+        ------
+        ValueError:
+            If endpoint name is not found
+        NotImplementedError:
+            Endpoint method not implemented
+        ValueError:
+            Path variables missing
 
         Returns
-            dict: Json dictionary response from api.
+        -------
+        dict
+            Tesla json response object.
 
         """
         path_vars = path_vars or {}
